@@ -17,13 +17,6 @@
 Base utilities to build API operation managers and objects on top of.
 """
 
-# Python 2.4 compat
-try:
-    all
-except NameError:
-    def all(iterable):
-        return True not in (not x for x in iterable)
-
 
 def getid(obj):
     """Abstracts the common pattern of allowing both an object or an
@@ -75,7 +68,7 @@ class Manager(object):
         return self._path(id)
 
     def _create(self, url, body):
-        resp, body = self.api.json_request('POST', url, data=body)
+        resp, body = self.api.json_request('POST', url, body=body)
         if body:
             return self.resource_class(self, body)
 
@@ -105,10 +98,15 @@ class Manager(object):
         return [obj_class(self, res, loaded=True) for res in data if res]
 
     def _update(self, url, body, response_key=None):
-        resp, body = self.api.json_request('PUT', url, data=body)
+        resp, body = self.api.json_request('PUT', url, body=body)
         # PUT requests may not return a body
         if body:
             return self.resource_class(self, body)
 
     def _delete(self, url):
         self.api.raw_request('DELETE', url)
+
+    def _patch(self, url, body, response_key=None):
+        resp, body = self.api.json_request('PATCH', url, body=body)
+        if body:
+            return self.resource_class(self, body)
